import * as __aws_sdk_types from "@aws-sdk/types";
/**
 * <p>Returns the objects or data listed below if successful. Otherwise, returns an error.</p>
 */
export interface GetTrailStatusOutput extends __aws_sdk_types.MetadataBearer {
    /**
     * <p>Whether the CloudTrail is currently logging AWS API calls.</p>
     */
    IsLogging?: boolean;
    /**
     * <p>Displays any Amazon S3 error that CloudTrail encountered when attempting to deliver log files to the designated bucket. For more information see the topic <a href="http://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html">Error Responses</a> in the Amazon S3 API Reference. </p> <note> <p>This error occurs only when there is a problem with the destination S3 bucket and will not occur for timeouts. To resolve the issue, create a new bucket and call <code>UpdateTrail</code> to specify the new bucket, or fix the existing objects so that CloudTrail can again write to the bucket.</p> </note>
     */
    LatestDeliveryError?: string;
    /**
     * <p>Displays any Amazon SNS error that CloudTrail encountered when attempting to send a notification. For more information about Amazon SNS errors, see the <a href="http://docs.aws.amazon.com/sns/latest/dg/welcome.html">Amazon SNS Developer Guide</a>. </p>
     */
    LatestNotificationError?: string;
    /**
     * <p>Specifies the date and time that CloudTrail last delivered log files to an account's Amazon S3 bucket.</p>
     */
    LatestDeliveryTime?: Date;
    /**
     * <p>Specifies the date and time of the most recent Amazon SNS notification that CloudTrail has written a new log file to an account's Amazon S3 bucket.</p>
     */
    LatestNotificationTime?: Date;
    /**
     * <p>Specifies the most recent date and time when CloudTrail started recording API calls for an AWS account.</p>
     */
    StartLoggingTime?: Date;
    /**
     * <p>Specifies the most recent date and time when CloudTrail stopped recording API calls for an AWS account.</p>
     */
    StopLoggingTime?: Date;
    /**
     * <p>Displays any CloudWatch Logs error that CloudTrail encountered when attempting to deliver logs to CloudWatch Logs.</p>
     */
    LatestCloudWatchLogsDeliveryError?: string;
    /**
     * <p>Displays the most recent date and time when CloudTrail delivered logs to CloudWatch Logs.</p>
     */
    LatestCloudWatchLogsDeliveryTime?: Date;
    /**
     * <p>Specifies the date and time that CloudTrail last delivered a digest file to an account's Amazon S3 bucket.</p>
     */
    LatestDigestDeliveryTime?: Date;
    /**
     * <p>Displays any Amazon S3 error that CloudTrail encountered when attempting to deliver a digest file to the designated bucket. For more information see the topic <a href="http://docs.aws.amazon.com/AmazonS3/latest/API/ErrorResponses.html">Error Responses</a> in the Amazon S3 API Reference. </p> <note> <p>This error occurs only when there is a problem with the destination S3 bucket and will not occur for timeouts. To resolve the issue, create a new bucket and call <code>UpdateTrail</code> to specify the new bucket, or fix the existing objects so that CloudTrail can again write to the bucket.</p> </note>
     */
    LatestDigestDeliveryError?: string;
    /**
     * <p>This field is deprecated.</p>
     */
    LatestDeliveryAttemptTime?: string;
    /**
     * <p>This field is deprecated.</p>
     */
    LatestNotificationAttemptTime?: string;
    /**
     * <p>This field is deprecated.</p>
     */
    LatestNotificationAttemptSucceeded?: string;
    /**
     * <p>This field is deprecated.</p>
     */
    LatestDeliveryAttemptSucceeded?: string;
    /**
     * <p>This field is deprecated.</p>
     */
    TimeLoggingStarted?: string;
    /**
     * <p>This field is deprecated.</p>
     */
    TimeLoggingStopped?: string;
    /**
     * Metadata about the response received, including the HTTP status code, HTTP headers, and any request identifiers recognized by the SDK.
     */
    $metadata: __aws_sdk_types.ResponseMetadata;
}
